@@ -1,3 +1,5 @@
+import shutil
+
 import fiftyone as fo
 
 
@@ -19,13 +21,17 @@ def load_yolov5_dataset(dataset_dir, dataset_name, label_field="ground_truth", s
 
 def export_yolov5_dataset(export_dir, dataset_or_view, label_field):
     # https://voxel51.com/docs/fiftyone/user_guide/export_datasets.html#yolov5dataset
-    # or https://docs.ultralytics.com/tutorials/train-custom-datasets/#3-organize-directories
+    # or https://docs.ultralytics.com/tutorials/train-custom-datasets/
+    shutil.rmtree(export_dir, ignore_errors=True)
+
     splits = dataset_or_view.distinct("tags")
 
     if not splits:
         splits = ["train"]
         dataset_or_view.tag_samples("train")
 
+    classes = dataset_or_view.default_classes
+
     for split in splits:
         print(f"\n[{split}]\n")
         split_view = dataset_or_view.match_tags(split)
@@ -35,8 +41,8 @@ def export_yolov5_dataset(export_dir, dataset_or_view, label_field):
             data_path=None,
             labels_path=None,
             label_field=label_field,
-            classes=dataset_or_view.default_classes,
-            split="val" if split == "validation" else split,
+            classes=classes,
+            split=split,
         )
 
     return export_dir
