@@ -1,10 +1,34 @@
+import json
 from collections import defaultdict
 from pathlib import Path
 
+import cv2 as cv
 import fiftyone.core.utils as fou
 import fiftyone.utils.iou as foui
 
 
+def equal_list(a: list, b: list) -> bool:
+    if len(a) != len(b):
+        return False
+
+    for _ai, _bi in zip(a, b):
+        if _ai != _bi:
+            return False
+
+    return True
+
+
+def equal_dict(a: dict, b: dict) -> bool:
+    if len(a) != len(b):
+        return False
+
+    for k, v in a.items():
+        if v != b.get(k):
+            return False
+
+    return True
+
+
 def _parse_text_slice(vals):
     assert len(vals) == 6
     x1, y1, x2, y2 = vals[:4]
@@ -125,12 +149,51 @@ def load_yolo_predictions(labels_path, classes):
     return db
 
 
+def load_coco_predictions(labels_path):
+    with open(labels_path, "r") as f:
+        coco = json.load(f)
+
+    assert "categories" in coco and "images" in coco and "annotations" in coco
+
+    imgs = {img["id"]: img for img in coco["images"]}
+    cats = {cat["id"]: cat for cat in coco["categories"]}
+
+    db = defaultdict(list)
+    for ann in coco["annotations"]:
+        _img = imgs[ann["image_id"]]
+
+        filepath = _img["file_name"]
+        height = _img["height"]
+        width = _img["width"]
+
+        _cat = cats[ann["category_id"]]
+
+        label = _cat["name"]
+
+        x, y, w, h = ann["bbox"]
+        bounding_box = [x / width, y / height, w / width, h / height]
+
+        confidence = ann.get("score", 1.0)
+
+        detection = dict(
+            bounding_box=bounding_box,
+            confidence=confidence,
+            label=label,
+        )
+        db[Path(filepath).stem].append(detection)
+
+    stems = [Path(_img["file_name"]).stem for _img in imgs.values()]
+    return {stem: db[stem] for stem in stems}
+
+
 def load_predictions(labels_path, classes=None, mode="text"):
     if mode == "text":
         return load_text_predictions(labels_path)
     elif mode == "yolo":
         assert isinstance(classes, list)
         return load_yolo_predictions(labels_path, classes)
+    elif mode == "coco":
+        return load_coco_predictions(labels_path)
     else:
         raise NotImplementedError
 
@@ -176,3 +239,48 @@ def find_duplicate_images(filepaths, leave_one_out=False):
                 results.extend(vals)
 
     return results
+
+
+def read_mask(mask_path, remap=None):
+    mask = cv.imread(mask_path, 0)
+
+    if remap is not None:
+        new_mask = mask.copy()
+        for _old, _new in remap.items():
+            if _old != _new:
+                new_mask[mask == _old] = _new
+        mask = new_mask
+
+    return mask
+
+
+def gen_mask_remap(dataset_mask_targets, label_mask_targets, ignore_index=255):
+    if equal_dict(dataset_mask_targets, label_mask_targets):
+        return None
+
+    label2index = {label: index for index, label in dataset_mask_targets.items()}
+
+    remap = {}
+    for index, label in label_mask_targets.items():
+        new_index = label2index.get(label, ignore_index)
+        if index != new_index:
+            remap[index] = new_index
+
+    remap = remap if remap else None
+    return remap
+
+
+def load_segmentation_masks(labels_path, remap=None, mode="png"):
+    labels_path = Path(labels_path)
+
+    if mode == "png":
+        assert labels_path.is_dir()
+    else:
+        raise NotImplementedError
+
+    db = {}
+    for mask_path in sorted(labels_path.glob("*.png")):
+        mask = read_mask(str(mask_path), remap)
+        db[mask_path.stem] = mask
+
+    return db
