@@ -148,75 +148,3 @@ def filter_samples(dataset, filter):
     """
     view = dataset.match(filter)
     return view
-
-
-def add_sample_field(dataset, field_name, ftype):
-    """Adds a new sample field or embedded field to the dataset, if necessary.
-
-    Args:
-        dataset: a :class:`fiftyone.core.dataset.Dataset`
-        field_name: the field name or `embedded.field.name`
-        ftype: the field type to create. Must be a subclass of :class:`fiftyone.core.fields.Field`
-    """
-    dataset.add_sample_field(field_name, ftype)
-
-
-def clear_sample_field(dataset, field_name):
-    """Clears the values of the field from all samples in the dataset.
-
-    Args:
-        dataset: a :class:`fiftyone.core.dataset.Dataset`
-        field_name: the field name or `embedded.field.name`
-    """
-    dataset.clear_sample_field(field_name)
-
-
-def clone_sample_field(dataset, field_name, new_field_name):
-    """Clones the given sample field into a new field of the dataset.
-
-    Args:
-        dataset: a :class:`fiftyone.core.dataset.Dataset`
-        field_name: the field name or `embedded.field.name`
-        new_field_name: the new field name or `embedded.field.name`
-    """
-    dataset.clone_sample_field(field_name, new_field_name)
-
-
-def delete_sample_field(dataset, field_name, error_level=0):
-    """Deletes the field from all samples in the dataset.
-
-    Args:
-        dataset: a :class:`fiftyone.core.dataset.Dataset`
-        field_name: the field name or `embedded.field.name`
-        error_level (int, optional): the error level to use
-    """
-    dataset.delete_sample_field(field_name, error_level=error_level)
-
-
-def rename_sample_field(dataset, field_name, new_field_name):
-    """Renames the sample field to the given new name.
-
-    Args:
-        dataset: a :class:`fiftyone.core.dataset.Dataset`
-        field_name: the field name or `embedded.field.name`
-        new_field_name: the new field name or `embedded.field.name`
-    """
-    dataset.rename_sample_field(field_name, new_field_name)
-
-
-def merge_labels(dataset, in_field, out_field):
-    """Merges the labels from the given input field into the given output field of the collection.
-
-    If this collection is a dataset, the input field is deleted after the
-    merge.
-
-    If this collection is a view, the input field will still exist on the
-    underlying dataset but will only contain the labels not present in this
-    view.
-
-    Args:
-        dataset: a :class:`fiftyone.core.dataset.Dataset`
-        in_field (str): the name of the input label field
-        out_field (str): the name of the output label field, which will be created if necessary
-    """
-    dataset.merge_labels(in_field, out_field)
