@@ -1,6 +1,7 @@
 from pathlib import Path
 
-tmpl_f32 = """# X3M SDK: Version_20220512
+tmpl_f32 = """\
+# X3M SDK: Version_20220512
 # https://developer.horizon.ai/api/v1/fileData/documents/ai_toolchain_develop/horizon_ai_toolchain_user_guide/chapter_3_model_conversion.html#model-conversion
 model_parameters:
   onnx_model: '{onnx_model}'
